bug-gnu-emacs
[Top][All Lists]
Advanced

[Date Prev][Date Next][Thread Prev][Thread Next][Date Index][Thread Index]

bug#10150: deactive->inactive, inactivate->deactivate spelling fixes


From: Paul Eggert
Subject: bug#10150: deactive->inactive, inactivate->deactivate spelling fixes
Date: Sun, 27 Nov 2011 15:38:47 -0800
User-agent: Mozilla/5.0 (X11; Linux i686; rv:7.0.1) Gecko/20110929 Thunderbird/7.0.1

Package: emacs
Severity: minor
Tags: patch

Standard English uses the adjective "inactive" and the verb
"deactivate"; "deactive" and "inactivate" are solecisms.
Emacs is pretty good about following standard usage but departs
from it in a few places in the API.  Here's a patch.  Since we're
in a feature freeze this should wait until after 24.1 is out.

-----

Fix misspellings of "deactivate" and "inactive".

* leim/quail/uni-input.el (ucs-input-deactivate):
Rename from ucs-input-inactivate.
* leim/quail/hangul.el (hangul-input-method-deactivate):
Rename from hangul-input-method-inactivate.
* lisp/emulation/viper-init.el (viper-deactivate-input-method-action):
Rename from viper-inactivate-input-method-action.
(viper-deactivate-input-method):
Rename from viper-inactivate-input-method.
* lisp/follow.el (follow-inactive-menu): Rename from follow-deactive-menu.
* lisp/international/mule-cmds.el (deactivate-input-method):
Rename from inactivate-input-method.
(deactivate-current-input-method-function):
Rename from inactivate-current-input-method-function.
(input-method-deactivate-hook):
Rename from input-method-inactivate-hook.
* lisp/international/quail.el (quail-deactivate):
Rename from quail-inactivate.
* lisp/international/robin.el (robin-deactivate):
Rename from robin-inactivate.

=== modified file 'leim/ChangeLog'
--- leim/ChangeLog      2011-11-20 19:35:27 +0000
+++ leim/ChangeLog      2011-11-27 23:29:49 +0000
@@ -1,3 +1,10 @@
+2011-11-27  Paul Eggert  <eggert@cs.ucla.edu>
+
+       * quail/uni-input.el (ucs-input-deactivate):
+       Rename from ucs-input-inactivate.
+       * quail/hangul.el (hangul-input-method-deactivate):
+       Rename from hangul-input-method-inactivate.
+
 2011-11-20  Juanma Barranquero  <lekktu@gmail.com>
 
        * quail/hangul.el (hangul-character): Fix typo.

=== modified file 'leim/quail/hangul.el'
--- leim/quail/hangul.el        2011-11-20 19:35:27 +0000
+++ leim/quail/hangul.el        2011-11-27 23:29:49 +0000
@@ -513,7 +513,7 @@
   "Activate Hangul input method INPUT-METHOD.
 FUNC is a function to handle input key.
 HELP-TEXT is a text set in `hangul-input-method-help-text'."
-  (setq inactivate-current-input-method-function 
'hangul-input-method-inactivate
+  (setq deactivate-current-input-method-function 
'hangul-input-method-deactivate
        describe-current-input-method-function 'hangul-input-method-help
        hangul-input-method-help-text help-text)
   (quail-delete-overlays)
@@ -521,8 +521,8 @@
       (add-hook 'minibuffer-exit-hook 'quail-exit-from-minibuffer))
   (set (make-local-variable 'input-method-function) func))
 
-(defun hangul-input-method-inactivate ()
-  "Inactivate the current Hangul input method."
+(defun hangul-input-method-deactivate ()
+  "Deactivate the current Hangul input method."
   (interactive)
   (unwind-protect
       (progn

=== modified file 'leim/quail/uni-input.el'
--- leim/quail/uni-input.el     2011-01-26 08:36:39 +0000
+++ leim/quail/uni-input.el     2011-11-27 23:29:49 +0000
@@ -99,7 +99,7 @@
            (quail-delete-overlays)
            (setq describe-current-input-method-function nil))
        (kill-local-variable 'input-method-function))
-    (setq inactivate-current-input-method-function 'ucs-input-inactivate)
+    (setq deactivate-current-input-method-function 'ucs-input-deactivate)
     (setq describe-current-input-method-function 'ucs-input-help)
     (quail-delete-overlays)
     (if (eq (selected-window) (minibuffer-window))
@@ -107,8 +107,8 @@
     (set (make-local-variable 'input-method-function)
         'ucs-input-method)))
 
-(defun ucs-input-inactivate ()
-  "Inactivate UCS input method."
+(defun ucs-input-deactivate ()
+  "Deactivate UCS input method."
   (interactive)
   (ucs-input-activate -1))
 

=== modified file 'lisp/ChangeLog'
--- lisp/ChangeLog      2011-11-27 08:33:25 +0000
+++ lisp/ChangeLog      2011-11-27 23:29:49 +0000
@@ -1,3 +1,21 @@
+2011-11-27  Paul Eggert  <eggert@cs.ucla.edu>
+
+       * emulation/viper-init.el (viper-deactivate-input-method-action):
+       Rename from viper-inactivate-input-method-action.
+       (viper-deactivate-input-method):
+       Rename from viper-inactivate-input-method.
+       * follow.el (follow-inactive-menu): Rename from follow-deactive-menu.
+       * international/mule-cmds.el (deactivate-input-method):
+       Rename from inactivate-input-method.
+       (deactivate-current-input-method-function):
+       Rename from inactivate-current-input-method-function.
+       (input-method-deactivate-hook):
+       Rename from input-method-inactivate-hook.
+       * international/quail.el (quail-deactivate):
+       Rename from quail-inactivate.
+       * international/robin.el (robin-deactivate):
+       Rename from robin-inactivate.
+
 2011-11-27  Nick Roberts  <nickrob@snap.net.nz>
 
        * progmodes/gdb-mi.el (gdb-init-1): Condition execution of

=== modified file 'lisp/emulation/viper-init.el'
--- lisp/emulation/viper-init.el        2011-11-23 07:03:56 +0000
+++ lisp/emulation/viper-init.el        2011-11-27 23:29:49 +0000
@@ -316,7 +316,7 @@
     ))
 
 ;; viper hook to run on input-method deactivation
-(defun viper-inactivate-input-method-action ()
+(defun viper-deactivate-input-method-action ()
   (if (null viper-mule-hook-flag)
       ()
     (setq viper-special-input-method nil)
@@ -328,9 +328,9 @@
                             (or current-input-method default-input-method))
                   "")))))
 
-(defun viper-inactivate-input-method ()
-  (cond ((and (featurep 'emacs) (fboundp 'inactivate-input-method))
-        (inactivate-input-method))
+(defun viper-deactivate-input-method ()
+  (cond ((and (featurep 'emacs) (fboundp 'deactivate-input-method))
+        (deactivate-input-method))
        ((and (featurep 'xemacs) (boundp 'current-input-method))
         ;; XEmacs had broken quail-mode for some time, so we are working around
         ;; it here
@@ -339,7 +339,7 @@
             (quail-delete-overlays))
         (setq describe-current-input-method-function nil)
         (setq current-input-method nil)
-        (run-hooks 'input-method-inactivate-hook)
+        (run-hooks 'input-method-deactivate-hook)
         (force-mode-line-update))
        ))
 (defun viper-activate-input-method ()
@@ -356,7 +356,7 @@
           ;; activate input method
           (viper-activate-input-method))
          (t ; deactivate input method
-          (viper-inactivate-input-method)))
+          (viper-deactivate-input-method)))
     ))
 
 

=== modified file 'lisp/emulation/viper.el'
--- lisp/emulation/viper.el     2011-11-19 09:18:31 +0000
+++ lisp/emulation/viper.el     2011-11-27 23:29:49 +0000
@@ -971,9 +971,9 @@
   (if (featurep 'emacs)
       (eval-after-load "mule-cmds"
        '(progn
-          (defadvice inactivate-input-method (after viper-mule-advice activate)
+          (defadvice deactivate-input-method (after viper-mule-advice activate)
             "Set viper-special-input-method to disable intl. input methods."
-            (viper-inactivate-input-method-action))
+            (viper-deactivate-input-method-action))
           (defadvice activate-input-method (after viper-mule-advice activate)
             "Set viper-special-input-method to enable intl. input methods."
             (viper-activate-input-method-action))
@@ -985,14 +985,14 @@
       '(progn
         (add-hook 'input-method-activate-hook
                   'viper-activate-input-method-action t)
-        (add-hook 'input-method-inactivate-hook
-                  'viper-inactivate-input-method-action t)))
+        (add-hook 'input-method-deactivate-hook
+                  'viper-deactivate-input-method-action t)))
     )
   (eval-after-load "mule-cmds"
     '(defadvice toggle-input-method (around viper-mule-advice activate)
        "Adjust input-method toggling in vi-state."
        (if (and viper-special-input-method (eq viper-current-state 'vi-state))
-          (viper-inactivate-input-method)
+          (viper-deactivate-input-method)
         ad-do-it)))
 
   ) ; viper-set-hooks

=== modified file 'lisp/follow.el'
--- lisp/follow.el      2011-11-27 04:43:11 +0000
+++ lisp/follow.el      2011-11-27 23:29:49 +0000
@@ -438,8 +438,8 @@
 (defvar follow-active-menu nil
   "The menu visible when Follow mode is active.")
 
-(defvar follow-deactive-menu nil
-  "The menu visible when Follow mode is deactivated.")
+(defvar follow-inactive-menu nil
+  "The menu visible when Follow mode is inactive.")
 
 (defvar follow-inside-post-command-hook nil
   "Non-nil when inside Follow modes `post-command-hook'.

=== modified file 'lisp/international/mule-cmds.el'
--- lisp/international/mule-cmds.el     2011-10-03 14:18:42 +0000
+++ lisp/international/mule-cmds.el     2011-11-27 23:29:49 +0000
@@ -1334,15 +1334,15 @@
 (make-variable-buffer-local 'input-method-history)
 (put 'input-method-history 'permanent-local t)
 
-(defvar inactivate-current-input-method-function nil
-  "Function to call for inactivating the current input method.
+(defvar deactivate-current-input-method-function nil
+  "Function to call for deactivating the current input method.
 Every input method should set this to an appropriate value when activated.
 This function is called with no argument.
 
 This function should never change the value of `current-input-method'.
-It is set to nil by the function `inactivate-input-method'.")
-(make-variable-buffer-local 'inactivate-current-input-method-function)
-(put 'inactivate-current-input-method-function 'permanent-local t)
+It is set to nil by the function `deactivate-input-method'.")
+(make-variable-buffer-local 'deactivate-current-input-method-function)
+(put 'deactivate-current-input-method-function 'permanent-local t)
 
 (defvar describe-current-input-method-function nil
   "Function to call for describing the current input method.
@@ -1429,7 +1429,7 @@
       (setq input-method (symbol-name input-method)))
   (if (and current-input-method
           (not (string= current-input-method input-method)))
-      (inactivate-input-method))
+      (deactivate-input-method))
   (unless (or current-input-method (null input-method))
     (let ((slot (assoc input-method input-method-alist)))
       (if (null slot)
@@ -1450,7 +1450,7 @@
          (run-hooks 'input-method-activate-hook)
        (force-mode-line-update)))))
 
-(defun inactivate-input-method ()
+(defun deactivate-input-method ()
   "Turn off the current input method."
   (when current-input-method
     (if input-method-history
@@ -1463,9 +1463,9 @@
        (progn
          (setq input-method-function nil
                current-input-method-title nil)
-         (funcall inactivate-current-input-method-function))
+         (funcall deactivate-current-input-method-function))
       (unwind-protect
-         (run-hooks 'input-method-inactivate-hook)
+         (run-hooks 'input-method-deactivate-hook)
        (setq current-input-method nil)
        (force-mode-line-update)))))
 
@@ -1479,7 +1479,7 @@
 which marks the variable `default-input-method' as set for Custom buffers.
 
 To deactivate the input method interactively, use \\[toggle-input-method].
-To deactivate it programmatically, use `inactivate-input-method'."
+To deactivate it programmatically, use `deactivate-input-method'."
   (interactive
    (let* ((default (or (car input-method-history) default-input-method)))
      (list (read-input-method-name
@@ -1516,7 +1516,7 @@
   (if toggle-input-method-active
       (error "Recursive use of `toggle-input-method'"))
   (if (and current-input-method (not arg))
-      (inactivate-input-method)
+      (deactivate-input-method)
     (let ((toggle-input-method-active t)
          (default (or (car input-method-history) default-input-method)))
       (if (and arg default (equal current-input-method default)
@@ -1643,11 +1643,11 @@
   :type 'hook
   :group 'mule)
 
-(defcustom input-method-inactivate-hook nil
-  "Normal hook run just after an input method is inactivated.
+(defcustom input-method-deactivate-hook nil
+  "Normal hook run just after an input method is deactivated.
 
 The variable `current-input-method' still keeps the input method name
-just inactivated."
+just deactivated."
   :type 'hook
   :group 'mule)
 

=== modified file 'lisp/international/quail.el'
--- lisp/language/korea-util.el 2011-01-26 08:36:39 +0000
+++ lisp/language/korea-util.el 2011-11-27 23:29:49 +0000
@@ -41,7 +41,7 @@
   "Turn on or off a Korean text input method for the current buffer."
   (interactive)
   (if current-input-method
-      (inactivate-input-method)
+      (deactivate-input-method)
     (activate-input-method
      (concat "korean-hangul" default-korean-keyboard))))
 

=== modified file 'lisp/mail/sendmail.el'
--- lisp/mail/sendmail.el       2011-10-15 16:35:19 +0000
+++ lisp/mail/sendmail.el       2011-11-27 23:29:49 +0000
@@ -613,7 +613,7 @@
   ;; (kill-local-variable 'enable-multibyte-characters)
   (set-buffer-multibyte (default-value 'enable-multibyte-characters))
   (if current-input-method
-      (inactivate-input-method))
+      (deactivate-input-method))
 
   ;; Local variables for Mail mode.
   (setq mail-send-actions actions)





reply via email to

[Prev in Thread] Current Thread [Next in Thread]
--- lisp/international/quail.el 2011-11-18 08:31:02 +0000
+++ lisp/international/quail.el 2011-11-27 23:29:49 +0000
@@ -544,10 +544,10 @@
   (if (and (overlayp quail-conv-overlay) (overlay-start quail-conv-overlay))
       (delete-overlay quail-conv-overlay)))
 
-(defun quail-inactivate ()
-  "Inactivate Quail input method.
+(defun quail-deactivate ()
+  "Deactivate Quail input method.
 
-This function runs the normal hook `quail-inactivate-hook'."
+This function runs the normal hook `quail-deactivate-hook'."
   (interactive)
   (quail-activate -1))
 
@@ -556,20 +556,20 @@
 With ARG, activate Quail input method if and only if arg is positive.
 
 This function runs `quail-activate-hook' if it activates the input
-method, `quail-inactivate-hook' if it deactivates it.
+method, `quail-deactivate-hook' if it deactivates it.
 
 While this input method is active, the variable
 `input-method-function' is bound to the function `quail-input-method'."
   (if (and arg
          (< (prefix-numeric-value arg) 0))
       ;; Let's inactivate Quail input method.
       (unwind-protect
          (progn
            (quail-delete-overlays)
            (setq describe-current-input-method-function nil)
            (quail-hide-guidance)
            (remove-hook 'post-command-hook 'quail-show-guidance t)
-           (run-hooks 'quail-inactivate-hook))
+           (run-hooks 'quail-deactivate-hook))
        (kill-local-variable 'input-method-function))
     ;; Let's activate Quail input method.
     (if (null quail-current-package)
@@ -579,7 +579,7 @@
              (setq name (car (car quail-package-alist)))
            (error "No Quail package loaded"))
          (quail-select-package name)))
-    (setq inactivate-current-input-method-function 'quail-inactivate)
+    (setq deactivate-current-input-method-function 'quail-deactivate)
     (setq describe-current-input-method-function 'quail-help)
     (quail-delete-overlays)
     (setq quail-guidance-str "")
@@ -594,7 +594,7 @@
     (setq input-method-function 'quail-input-method)))
 
 (defun quail-exit-from-minibuffer ()
-  (inactivate-input-method)
+  (deactivate-input-method)
   (if (<= (minibuffer-depth) 1)
       (remove-hook 'minibuffer-exit-hook 'quail-exit-from-minibuffer)))
 
@@ -556,20 +556,20 @@
   (if (and arg
          (< (prefix-numeric-value arg) 0))
-      ;; Let's inactivate Quail input method.
+      ;; Let's deactivate Quail input method.
       (unwind-protect
          (progn

=== modified file 'lisp/international/robin.el'
--- lisp/international/robin.el 2011-11-13 07:48:23 +0000
+++ lisp/international/robin.el 2011-11-27 23:29:49 +0000
@@ -390,8 +390,8 @@
     (setq robin-current-package-name name)
     (robin-activate)))
 
-(defun robin-inactivate ()
-  "Inactivate robin input method."
+(defun robin-deactivate ()
+  "Deactivate robin input method."
 
   (interactive)
   (robin-activate -1))
@@ -406,18 +406,18 @@
   (if (and arg
           (< (prefix-numeric-value arg) 0))
 
       ;; inactivate robin input method.
       (unwind-protect
          (progn
            (setq robin-mode nil)
            (setq describe-current-input-method-function nil)
-           (run-hooks 'robin-inactivate-hook))
+           (run-hooks 'robin-deactivate-hook))
        (kill-local-variable 'input-method-function))
 
     ;; activate robin input method.
     (setq robin-mode t
          describe-current-input-method-function 'robin-help
-         inactivate-current-input-method-function 'robin-inactivate)
+         deactivate-current-input-method-function 'robin-deactivate)
     (if (eq (selected-window) (minibuffer-window))
        (add-hook 'minibuffer-exit-hook 'robin-exit-from-minibuffer))
     (run-hooks 'input-method-activate-hook
@@ -426,7 +426,7 @@
         'robin-input-method)))
 
 (defun robin-exit-from-minibuffer ()
-  (inactivate-input-method)
+  (deactivate-input-method)
   (if (<= (minibuffer-depth) 1)
       (remove-hook 'minibuffer-exit-hook 'robin-exit-from-minibuffer)))
 
@@ -406,18 +406,18 @@
           (< (prefix-numeric-value arg) 0))
 
-      ;; inactivate robin input method.
+      ;; deactivate robin input method.
       (unwind-protect
          (progn

=== modified file 'lisp/language/korea-util.el'